import React, { useState, useRef, useEffect, useMemo } from "react";
import { Box, Card, CardContent, Grid, Typography, Tooltip } from '@mui/material';
import {
    useTranslate,
    useRecordContext,
} from 'react-admin';
import PanelTypography from "@/page/components/PanelTypography";
import * as Common from '@/utils/common'

const WarehousePanel = () => {
    const record = useRecordContext();
    if (!record) return null;
    const translate = useTranslate();
    return (
        <>
            <Card sx={{ width: { xs: 300, sm: 500, md: 600, lg: 800 }, margin: 'auto' }}>
                <CardContent>
                    <Grid container spacing={2}>
                        <Grid item xs={12} sx={{ display: 'flex', justifyContent: 'space-between' }}>
                            <Typography variant="h6" gutterBottom align="left" sx={{
                                maxWidth: { xs: '100px', sm: '180px', md: '260px', lg: '360px' },
                                whiteSpace: 'nowrap',
                                overflow: 'hidden',
                                textOverflow: 'ellipsis',
                            }}>
                                {Common.camelToPascalWithSpaces(translate('table.field.warehouse.name'))}: {record.name}
                            </Typography>
                            {/*  inherit, primary, secondary, textPrimary, textSecondary, error */}
                            <Typography variant="h6" gutterBottom align="right" >
                                ID: {record.id}
                            </Typography>
                        </Grid>
                    </Grid>
                    <Grid container spacing={2}>
                        <Grid item xs={12} container alignContent="flex-end">
                            <Typography variant="caption" color="textSecondary" sx={{ wordWrap: 'break-word', wordBreak: 'break-all' }}>
                                {Common.camelToPascalWithSpaces(translate('common.field.memo'))}:{record.memo}
                            </Typography>
                        </Grid>
                    </Grid>
                    <Box height={20}>&nbsp;</Box>
                    <Grid container spacing={2}>
                        <Grid item xs={6}>
                            <PanelTypography
                                title="table.field.warehouse.name" 
                                property={record.name}
                            />
                        </Grid>
                        <Grid item xs={6}>
                            <PanelTypography
                                title="table.field.warehouse.code" 
                                property={record.code}
                            />
                        </Grid>
                        <Grid item xs={6}>
                            <PanelTypography
                                title="table.field.warehouse.factory" 
                                property={record.factory}
                            />
                        </Grid>
                        <Grid item xs={6}>
                            <PanelTypography
                                title="table.field.warehouse.address" 
                                property={record.address}
                            />
                        </Grid>
                        <Grid item xs={3}>
                            <PanelTypography
                                title="table.field.warehouse.longitude" 
                                property={record.longitude}
                            />
                        </Grid>
                        <Grid item xs={3} >
                            <PanelTypography
                                title="table.field.warehouse.latgitude" 
                                property={record.latgitude}
                            />
                        </Grid>
                        <Grid item xs={2}>
                            <PanelTypography
                                title="table.field.warehouse.length" 
                                property={record.length}
                            />
                        </Grid>
                        <Grid item xs={2}>
                            <PanelTypography
                                title="table.field.warehouse.width" 
                                property={record.width}
                            />
                        </Grid>
                        <Grid item xs={2}>
                            <PanelTypography
                                title="table.field.warehouse.height" 
                                property={record.height}
                            />
                        </Grid>

                    </Grid>
                </CardContent>
            </Card >
        </>
    );
};

export default WarehousePanel;
